@@ -9,10 +9,11 @@ around execute => sub ($execute, $c) {
   my $l       = $c->language;
   my $preview = $c->is_user_authenticated && $c->param('прегледъ');
   my $user    = $c->user;
-  state $json_path      = '/paths/~1страници/get/parameters/3/default';
+  state $json_path      = '/paths/~1страници/get/parameters/4/default';
   state $list_columns   = $c->openapi_spec($json_path);
   state $not_found_id   = $c->not_found_id;
   state $not_found_code = $c->not_found_code;
+
   my $str = $c->stranici;
   my $page = $str->find_for_display($alias, $user, $c->domain, $preview);
   $page //= $str->find($not_found_id);
@@ -23,16 +24,22 @@ around execute => sub ($execute, $c) {
 
   #These are always used so we add them to the stash earlier.
   $c->stash(
-          celini       => $celini,
-          list_columns => $list_columns,
-          page         => $page,
-          preview      => $preview,
-          user         => $user,
-          c2a          => {
-            'белѣжка' => beleyazhka => 'въпросъ' => wyprosy => 'заглавѥ' =>
-              zaglawie => 'книга' => kniga => 'писанѥ' => pisanie => 'цѣлина' =>
-              ceyalina => 'ѿговоръ' => 'otgowory'
-          },
+    celini       => $celini,
+    list_columns => $list_columns,
+    page         => $page,
+    preview      => $preview,
+    user         => $user,
+
+    # data_type to template name
+    d2t => {
+            'белѣжка' => '_beleyazhka',
+            'въпросъ' => '_wyprosy',
+            'заглавѥ' => '_zaglawie',
+            'книга'   => '_kniga',
+            'писанѥ'  => '_pisanie',
+            'цѣлина'  => '_ceyalina',
+            'ѿговоръ' => '_otgowory'
+           },
   );
 
   if ($page->{id} == $not_found_id) {
